@@ -192,7 +192,7 @@ class Command(hooks.utils.Command):  # pylint: disable=too-many-instance-attribu
         if not self.clean_build:
             parser.add_argument('--clean', action='store_true', help='Start from a clean build directory')
 
-        known_args, self.args = parser.parse_known_args(args)
+        known_args, self.args = parser.parse_known_args(args[1:])
 
         self.cmake = known_args.cmake
         self.all_at_once = known_args.all_at_once
@@ -274,24 +274,27 @@ class Command(hooks.utils.Command):  # pylint: disable=too-many-instance-attribu
                     ]
                 )
 
-                compiledb = Path(self.build_dir, 'compile_commands.json')
                 if result.returncode == 0:
+                    compiledb = Path(self.build_dir, 'compile_commands.json')
                     if not compiledb.exists():
                         result.returncode = 1
                         result.stderr += f'\nUnable to locate {compiledb}\n\n'
                     else:
                         compiledb_srcdir = Path(self.source_dir, 'compile_commands.json')
-
-                        # If it's not a symbolic link to the compilation database in the build directory, replace it
-                        if compiledb_srcdir.is_symlink() and compiledb_srcdir.resolve() != compiledb:
+                        if compiledb_srcdir.is_symlink() and compiledb_srcdir.resolve() == compiledb:
+                            # If it's a symbolic link and points to the compilation database in the build directory,
+                            # we're all good.
+                            pass
+                        else:
+                            # In all other cases, we copy the compilation database into the source directory
+                            if compiledb_srcdir.is_symlink():
+                                if self.debug:
+                                    print(f'DEBUG removing symbolic link at: {compiledb_srcdir}')
+                                compiledb_srcdir.unlink()
                             if self.debug:
-                                print(f'DEBUG removing symbolic link at: {compiledb_srcdir}')
-                            compiledb_srcdir.unlink()
-                        if self.debug:
-                            print(f'DEBUG copying compilation database from {self.build_dir} to {self.source_dir}')
-                        shutil.copy(compiledb, self.source_dir)
-
-                if result.returncode != 0:
+                                print(f'DEBUG copying compilation database from {self.build_dir} to {self.source_dir}')
+                            shutil.copy(compiledb, self.source_dir)
+                else:
                     sys.stdout.write(result.stdout)
                     sys.stderr.write(result.stderr)
                     sys.stdout.flush()
@@ -310,7 +313,7 @@ class Command(hooks.utils.Command):  # pylint: disable=too-many-instance-attribu
         if returncode != 0:
             sys.exit(returncode)
 
-    def _parse_output(self, result):  # pylint: disable=no-self-use,unused-argument
+    def _parse_output(self, result):  # pylint: disable=unused-argument
         return NotImplemented
 
     def _call_process(self, args, **kwargs):
